@@ -7,12 +7,11 @@ from json import JSONDecodeError
 
 import requests
 
-__version__ = "0.4.2"
+__version__ = "0.5.0"
 __author__ = "Kartik Talwar"
 __email__ = "hi@kartikt.com"
 __url__ = "https://github.com/KartikTalwar/duolingo"
 
-
 class Struct:
     def __init__(self, **entries):
         self.__dict__.update(entries)
@@ -48,7 +47,6 @@ class Duolingo(object):
         self.username = username
         self.password = password
         self.session_file = session_file
-        self.user_url = "https://duolingo.com/users/%s" % self.username
         self.session = requests.Session()
         self.leader_data = None
         self.jwt = jwt
@@ -117,9 +115,16 @@ class Duolingo(object):
                 json.dump({"jwt_session": self.jwt}, f)
 
     def _check_login(self):
-        resp = self._make_req(self.user_url)
+        resp = self._make_req(self.get_user_url())
         return resp.status_code == 200
 
+    def get_user_url(self):
+        return "https://duolingo.com/users/%s" % self.username
+
+    def set_username(self, username):
+        self.username = username
+        self.user_data = Struct(**self._get_data())
+
     def get_leaderboard(self, unit, before):
         """
         Get user's rank in the week in descending order, stream from
@@ -220,8 +225,11 @@ class Duolingo(object):
         """
         Get user's data from ``https://www.duolingo.com/users/<username>``.
         """
-        get = self._make_req(self.user_url).json()
-        return get
+        get = self._make_req(self.get_user_url())
+        if get.status_code == 404:
+            raise Exception('User not found')
+        else:
+            return get.json()
 
     @staticmethod
     def _make_dict(keys, array):
@@ -606,6 +614,11 @@ class Duolingo(object):
         daily_progress_request = self._make_req(daily_progress_url)
         daily_progress = daily_progress_request.json()
 
+        if not daily_progress:
+            raise DuolingoException(
+                "Could not get daily XP progress for user \"{}\". Are you logged in as that user?".format(self.username)
+            )
+
         # xpGains lists the lessons completed on the last day where lessons were done.
         # We use the streakData.updatedTimestamp to get the last "midnight", and get lessons after that.
         last_midnight = daily_progress['streakData']['updatedTimestamp']
